@@ -267,7 +267,7 @@ class DYSManager:
             headers["X-Lang"] = x_lang
         params = {"addCopyOfPrefix": add_copy_of_prefix}
         if parent_folder_cid:
-            params = {"targetFolderCid": parent_folder_cid}
+            params.update({"targetFolderCid": parent_folder_cid})
         res = self.make_dys_request("POST", url, headers, params=params)
         return res
 
